## v0.0.11 (2025-12-30)

### 🔀 Others
- modify readme.md

## v0.0.10 (2025-12-30)

### 🔀 Others
- modify readme.md

## v0.0.9 (2025-12-30)

### 🔀 Others
- modify pyproject.toml

## v0.0.8 (2025-12-30)

### 🔀 Others
- modify epub_tool.py

## v0.0.7 (2025-12-30)

### 🔀 Others
- modify projects scripts

## v0.0.6 (2025-12-30)

### 🔀 Others
- modify projects scripts
- modify projects scripts

## v0.0.5 (2025-12-30)

### 🔀 Others
- modify projects scripts
- modify projects scripts

## v0.0.4 (2025-12-30)

### 🔀 Others
- modify projects scripts

## v0.0.3 (2025-12-30)

### 🔀 Others
- support syncmeta

## v0.0.2 (2025-12-30)

### 🔀 Others
- init
